@@ -185,6 +185,20 @@ static const canon_cap_t canon_model_capabilities[] =
     NULL,
     NULL
   },
+  { /* Canon PIXMA MP970 */
+    "PIXMA MP970", 3,          /*model, model_id*/
+    842, 17*72,       /* max paper width and height */
+    10, 10, 15, 15,    /*border_left, border_right, border_top, border_bottom */
+    8,
+    &canon_PIXMA_iP4000_slotlist,
+    CANON_CAP_STD0|CANON_CAP_DUPLEX|CANON_CAP_r|CANON_CAP_px|CANON_CAP_I,0x64,control_cmd_MULTIPASS_MP150,  /*features */
+    &canon_MULTIPASS_MP970_modelist,
+    &canon_PIXMA_iP4000_paperlist,
+    NULL,
+    NULL,
+    NULL,
+    NULL
+  },
   /* ******************************** */
   /*                                  */
   /* tested and color-adjusted models */
